# type = forsale|rent
import requests
from .common import get_std_headers
import json


def fetch_yad2_nadlan_for_sale_page(page, city, tp):
    payload = {'city': city, 'forceLoad': 'true', 'page': page}

    try:
        with requests.get(f'https://gw.yad2.co.il/feed-search-legacy/realestate/{tp}',
                          params=payload,
                          headers=get_std_headers('https://www.yad2.co.il/')) as r:
            if r.status_code == 200:
                return r.text, r.status_code
            else:
                return r.url, r.status_code
    except:
        return str(payload), -1


def load_estate(args):
    city = args['city']
    page = args['page']
    tp = args['type']
    ret = {}

    payload, status_code = fetch_yad2_nadlan_for_sale_page(page, city, tp)
    ret['status'] = status_code
    ret['page'] = page
    ret['city'] = city
    if status_code == 200:
        raw_data = json.loads(payload)
        total_pages = raw_data['data']['pagination']['last_page']
        ret['total_pages'] = total_pages
        ret['data'] = []
        if 'data' in raw_data.keys():
            data = raw_data['data']
            if 'feed' in data.keys():
                feed = data['feed']
                if 'feed_items' in feed.keys():
                    ret['data'] = feed['feed_items']
    else:
        ret['url'] = payload

    return ret


# https://www.yad2.co.il/api/item/en2h6jnz/contactinfo?id=en2h6jnz
def fetch_yad2_nadlan_additional_info(url, link, query):
    payload = {query: link}

    try:
        with requests.get(url, params=payload, headers=get_std_headers('https://www.yad2.co.il/')) as r:
            if r.status_code == 200:
                return r.text, r.status_code
            else:
                return r.url, r.status_code
    except Exception:
        return f'{url}?{query}={link}', -1


def load_additional_info(is_contact, args):
    params = args['params']
    ret = {'data': []}
    for p in params:
        ad_number = p['ad_number']
        link = p['link']
        if not is_contact:
            url = "https://gw.yad2.co.il/feed-search-legacy/item"
            query = "token"
        else:
            url = f"https://www.yad2.co.il/api/item/{link}/contactinfo"
            query = "id"
        payload, status_code = fetch_yad2_nadlan_additional_info(url, link, query)
        obj = {'ad_number': ad_number, 'link': link, 'payload': payload, 'status': status_code}
        ret['data'].append(obj)
    return ret



import json

import requests


def load_page_from_nadlan_impl(label, city_id, page):
    payload = {
        "MoreAssestsType": 0,
        "FillterRoomNum": 0,
        "GridDisplayType": 0,
        "ResultLable": label,
        "ResultType": 1,
        "ObjectID": str(city_id),
        "ObjectIDType": "text",
        "ObjectKey": "UNIQ_ID",
        "DescLayerID": "SETL_MID_POINT",
        "Alert": None,

        "Gush": "",
        "Parcel": "",
        "showLotParcel": True,
        "showLotAddress": True,
        "OriginalSearchString": label,
        "MutipuleResults": False,
        "ResultsOptions": None,
        "CurrentLavel": 2,
        "Navs": [
            {

            }
        ],
        "QueryMapParams": {
            "QueryToRun": None,
            "QueryObjectID": str(city_id),
            "QueryObjectType": "number",
            "QueryObjectKey": "SETL_CODE",
            "QueryDescLayerID": "KSHTANN_SETL_AREA",
            "SpacialWhereClause": None
        },
        "isHistorical": True,
        "PageNo": page,
        "OrderByFilled": "DEALDATETIME",
        "OrderByDescending": True,
        "Distance": 0
    }

    headers = {'Connection': 'keep-alive',
               'sec-ch-ua': '"Chromium";v="104", " Not A;Brand";v="99", "Google Chrome";v="104"',
               'Accept': 'application/json, text/plain, */*',
               'mainsite_version_commit': '3376126e2fad3570e3a7cd8102badd16e5644759',
               'mobile-app': 'false',
               'sec-ch-ua-mobile': '?0',
               'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.5112.79 Safari/537.36',
               'sec-ch-ua-platform': '"Linux"',
               'Origin': 'https://www.nadlan.gov.il',
               'Sec-Fetch-Site': 'same-site',
               'Sec-Fetch-Mode': 'cors',
               'Sec-Fetch-Dest': 'empty',
               'Referer': 'https://www.nadlan.gov.il/',
               'Accept-Encoding': 'gzip, deflate, br',
               'Accept-Language': 'en-US,en;q=0.9'}

    with requests.post("https://www.nadlan.gov.il//Nadlan.REST/Main/GetAssestAndDeals", json=payload,
                       headers=headers) as r:
        return r.text, r.status_code


def load_page_from_nadlan(args):
    label = args['label']
    city_id = int(args['city_id'])
    page = int(args['page'])
    res = {}
    try:
        text, code = load_page_from_nadlan_impl(label, city_id, page)
        res['code'] = code
        if code == 200:
            res['data'] = json.loads(text)
        else:
            res['data'] = None
    except:
        res['code'] = -1
        res['data'] = None
    return res



from .nadlan import load_page_from_nadlan
from .yad2 import load_estate, load_additional_info


def fetch(args):
    command = args['command']
    if command == 'load_estate':
        return load_estate(args)
    elif command == 'additional_info':
        return load_additional_info(False, args)
    elif command == 'nadlan.gov.il':
        return load_page_from_nadlan(args)
    else:
        return None



def get_std_headers(url):
    return {'Connection': 'keep-alive',
            'sec-ch-ua': '"Chromium";v="104", " Not A;Brand";v="99", "Google Chrome";v="104"',
            'Accept': 'application/json, text/plain, */*',
            'mainsite_version_commit': '3376126e2fad3570e3a7cd8102badd16e5644759',
            'mobile-app': 'false',
            'sec-ch-ua-mobile': '?0',
            'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.5112.79 Safari/537.36',
            'sec-ch-ua-platform': '"Linux"',
            'Origin': url,
            'Sec-Fetch-Site': 'same-site',
            'Sec-Fetch-Mode': 'cors',
            'Sec-Fetch-Dest': 'empty',
            'Referer': url,
            'Accept-Encoding': 'gzip, deflate, br',
            'Accept-Language': 'en-US,en;q=0.9'}
